@@ -28,7 +28,7 @@ from .ped import parse_ped
 from .utils import optimize_coords
 from .vcf import parse_vcf
 
-logging.basicConfig(level=logging.INFO, format="[%(levelname)s] %(message)s")
+logging.basicConfig(level=logging.DEBUG, format="[%(levelname)s] %(message)s")
 logger = logging.getLogger("covviz")
 
 
@@ -202,7 +202,10 @@ def cli():
 
     logger.info("parsing bed file (%s)" % args.bed)
 
-    exclude = re.compile(args.exclude.replace("~", "").replace(",", "|"))
+    if args.exclude:
+        exclude = re.compile(args.exclude.replace("~", "").replace(",", "|"))
+    else:
+        exclude = re.compile(r"/")
 
     traces = parse_bed(
         args.bed,
